addpath('LIB')

%{
AUTHOR:        Nikolai Yurttagl
DATE:          21-02-2019

This script calculates a small distribution of tunnel conductances for a given
set of voltages at a constant temperature.

%}

% Island Capacitance
C0 = 669.8e-15;

% Capacitance to Ground
CG = 1.8e-15;

% Tunnel resistance
R0 = 35e3;

% Number of islands in series
N_SERIES = 35;

% Asymptotic tunnel conductance
Gt = 1/((N_SERIES+1)*R0);

% Electron temperature
T0 = 0.455e-3;

% Number of random offset charges taken into account for a single linear
% array
REPEATS = 100;

% Logarithmic voltage array

VOLTAGE = [-fliplr(3*logspace(-7,-5,50)) 3*logspace(-7,-5,50)];

% Here we use a smaller number of steps because the Markov model converges
% faster at higher bias. Very close to zero bias there is a larger standard
% deviation. Changing the number of steps to 1e6 improves this.

STEPS   = 1.0e+5.*ones(length(VOLTAGE),1);

V_SCALE = -1e-3:1e-7:1e-3;

dG  = zeros(REPEATS,length(VOLTAGE));
dI  = zeros(2*REPEATS,length(VOLTAGE));
dV  = zeros(2*REPEATS,length(VOLTAGE));
POS = 1;

for i=1:length(VOLTAGE)
    
for j=1:REPEATS    
    
% Create a random offset charge configuration    
    
dQ_LIM_1 = -0.5;
dQ_LIM_2 = 0.5;
OFFSET_CHARGE = (dQ_LIM_2-dQ_LIM_1).*rand(N_SERIES,1) + dQ_LIM_1;   
    
% The function MARKOV_RANGE estimates a dynamic bias range based on the
% master equation tunneling model.

dV = MARKOV_RANGE_CAL(V_SCALE,VOLTAGE(i),N_SERIES,C0,R0,T0);  
disp([num2str(dV(1)) ' V to ' num2str(dV(2)) ' V'])

% Calculate the current at the given input voltage using the Markov Model

V = [dV(1) dV(2)]; 
I = ISLAND_ARRAY_PHI_IV(N_SERIES,C0,CG,R0,T0,V,OFFSET_CHARGE,(STEPS(i)).*ones(length(V),1));

% Calculate the differential conductance and store the current and voltage

X = [ones(length(V),1) V'];
FIT = X\(I');

dG(j,i) = FIT(2);

dI(POS:POS+1,i) = I;
dV(POS:POS+1,i) = V;

POS = POS+2;

end

POS = 1;

end

save DATA/ULT_ISOTHERM_FIT.mat dI dV dG Gt C0 CG R0 T0 VOLTAGE STEPS N_SERIES
