function [dV] = MARKOV_RANGE_CAL(V,...
                                 V0,...
                                 N,...
                                 C0,...
                                 R0,...
                                 T)

%{
FUNCTION NAME: MARKOV_RANGE_CAL
AUTHOR:        Nikolai Yurttagl
DATE:          21-02-2019

The function MARKOV_RANGE_CAL calculates a bias range for calculating the
differential conductance from a linear fit of the IV curve with an
error <0.5 percent. The single electron model using the master equation
the tunneling rates is utilized for this.
%}
         

    [~,G,Gt] = MASTER_EQUATION_IV(V,N,C0,R0,T);
    
    G_VAL = G./Gt;
    
    G_POS = find(abs(V0-V)==min(abs(V0-V)));
    
    STEPS = 0; RANGE = 1e-4; dN_L = 0; dN_R = 0;
    
    while STEPS*1e-7 < RANGE
        
        dN_L = dN_L + 1*(abs(1-G_VAL(G_POS)/G_VAL(G_POS-STEPS))<5.0e-4);
        dN_R = dN_R + 1*(abs(1-G_VAL(G_POS)/G_VAL(G_POS+STEPS))<5.0e-4);
        STEPS = STEPS + 1;
        
    end
       
    if abs(V(G_POS-dN_L)-V(G_POS)) < abs(V(G_POS+dN_R)-V(G_POS))
        
        dV = [V(G_POS-dN_L); V(G_POS+dN_L)];
        
    end
    
    if abs(V(G_POS+dN_R)-V(G_POS)) <= abs(V(G_POS-dN_L)-V(G_POS))
        
        dV = [V(G_POS-dN_R); V(G_POS+dN_R)];
        
    end
    
end