function [CURRENT,G,Gt] = MASTER_EQUATION_IV(VOLTAGE,...
                                             N,...
                                             C0,...
                                             R,...
                                             T0)

%{
FUNCTION NAME: MASTER_EQUATION_IV
AUTHOR:        Nikolai Yurttagl (ported from pyCBT)
DATE:          21-02-2019

The function MASTER_EQUATION_IV calculates the current from a given set
of input voltages for a linear array of N junctions, each with resistance R
at temperature T0. Each island has a capacitance of C0. The function is a 
port from python to matlab from the library pyCBT. Credits for development
of the code and questions for support should be addressed to the authors of pyCBT
%}


[dataFilePath,...
 dataFileName, ~] = fileparts('INIT.ini');
metaDataFile      = fullfile(dataFilePath, [dataFileName '.ini']);
metadata          = INI2STRUCT(metaDataFile);
e                 = str2double(metadata.constants.elem_charge);
k                 = str2double(metadata.constants.boltz_const);

n_max = 330;
C0 = C0*N/(N-1);
Gt  = 1/(N*R);
CURRENT = zeros(length(VOLTAGE),1);

for s=1:length(T0)
    
    T = T0(s);

for j=1:length(VOLTAGE)
    
    V = VOLTAGE(j)/(N/2);

sigma2 = (GAMMA1PLUS(-1,V,T,R,C0,e,k) + GAMMA2MINUS(-1,V,T,R,C0,e,k)...
         +GAMMA1MINUS(1,V,T,R,C0,e,k) + GAMMA2PLUS(1,V,T,R,C0,e,k))/...
         (GAMMA1PLUS(0,V,T,R,C0,e,k)  + GAMMA1MINUS(0,V,T,R,C0,e,k)+...
          GAMMA2PLUS(0,V,T,R,C0,e,k)  + GAMMA2MINUS(0,V,T,R,C0,e,k));
         
sigma = [1; 1/sigma2];

ref_curr = sigma(1)*(GAMMA1PLUS(0,V,T,R,C0,e,k)-GAMMA1MINUS(0,V,T,R,C0,e,k));

current = ref_curr...
        + sigma(2)*((GAMMA1PLUS(1,V,T,R,C0,e,k)-GAMMA1MINUS(1,V,T,R,C0,e,k))...
        +(GAMMA1PLUS(-1,V,T,R,C0,e,k)-GAMMA1MINUS(-1,V,T,R,C0,e,k)));

stop_calculation = 0;

for i=2:n_max
    
    if stop_calculation == 0
        
    sigma2 = (-GAMMA1PLUS(i-2,V,T,R,C0,e,k)*sigma(i-1)-GAMMA2MINUS(i-2,V,T,R,C0,e,k)*sigma(i-1)...
             +GAMMA1PLUS(i-1,V,T,R,C0,e,k)*sigma(i)+GAMMA1MINUS(i-1,V,T,R,C0,e,k)*sigma(i)...
             +GAMMA2PLUS(i-1,V,T,R,C0,e,k)*sigma(i)+GAMMA2MINUS(i-1,V,T,R,C0,e,k)*sigma(i))/...
             (GAMMA1MINUS(i,V,T,R,C0,e,k)+GAMMA2PLUS(i,V,T,R,C0,e,k));
                      
    sigma = [sigma; sigma2];
    
    current_curr_plus = sigma(i+1)*(GAMMA1PLUS(i,V,T,R,C0,e,k)-GAMMA1MINUS(i,V,T,R,C0,e,k));
    current_curr_minus = sigma(i+1)*(GAMMA1PLUS(-i,V,T,R,C0,e,k)-GAMMA1MINUS(-i,V,T,R,C0,e,k));
    
    current = current + current_curr_plus + current_curr_minus;
    
    if abs((abs(current_curr_plus+current_curr_minus))/ref_curr)<1e-12
    stop_calculation=1;
    end
   
    end
    
end

sigma_sum = sigma(1)+2*sum(sigma(2:length(sigma)));
CURRENT(j) = current*e/sigma_sum;

end

G=PROCESS_NUMDIFF(CURRENT,VOLTAGE);

end

end

