from IPython.core.display import display, HTML
display(HTML("<style>.container { width:100% !important; }</style>"))
display(HTML("<style> #notebook-container {padding-bottom: 100% !important; }</style>"))

import numpy as np
import pandas as pd
import matplotlib, json, codecs, scipy, scipy.constants
import scipy.stats
import scipy.signal

import cbt_tools1
import cbt_fit_tools
import os  
import mjsutils as m

e = scipy.constants.e
k_B = scipy.constants.Boltzmann

import matplotlib.pyplot as plt
#from matplotlib import rc
#rc('text', usetex=True)
#matplotlib.rcParams['text.usetex'] = True
#matplotlib.rcParams['text.latex.unicode'] = True

plt.rcParams['text.usetex'] = False 
plt.rcParams['font.family'] = 'serif'
plt.rcParams['figure.dpi'] = 110
plt.rcParams['axes.grid'] = True
plt.rcParams['figure.figsize'] = [4.0, 3.0]

plt.rcParams['xtick.direction'] = 'in'
plt.rcParams['ytick.direction'] = 'in'
plt.rcParams['ytick.right'] = True
plt.rcParams['xtick.top'] = True



d = {}
df = {}

def loadin_jsonl(filename):
    return pd.DataFrame(list(map(lambda x: json.loads(x) if len(x)>0 else {},codecs.open(filename).read().split('\n'))))

def loadin(*filenames): # a way to load in many different files and keep track of them. 
    for filename in filenames:
        
        if isinstance(filename, int):
            filename = str(filename).zfill(4)
        
        for file in os.listdir("../data/"):
            if file.endswith(filename+".json"):
                filename = os.path.join("../data/", file)
                print(filename)
        
        
        datafile = json.loads( codecs.open(filename,'r','utf-8').read() )
        key = datafile['attr']['_file counter']
        d[key]= datafile
        
        if len(datafile['data'].keys()) == 0:
            #try to load in the jsonl
            print('loading jsonl for ',filename)
            if os.path.isfile(filename+'.jsonl'):
                df[key] = loadin_jsonl(filename+'.jsonl')
            else:
                print(filename, 'is empty')
                del d[key]
                
            
        else:
            df[key] = pd.DataFrame(datafile['data'])

def smooth(x,n):
    return scipy.signal.savgol_filter(x,n,3,mode='nearest')
    
    
def rolling_quadratic(x,y):
    P = np.polyfit(x,y,2)
    #plt.plot(x,y,'ro')
    #plt.plot(x,np.polyval(P,x))
    #the peak of this fit is
    y0 = -1.0*P[1]**2/4/P[0] + P[2]
    x0 = -1 * P[1] / 2 / P[0]
    #plt.plot([x0],[y0],'o')
    if x0 > np.min(x) and x0 < np.max(x):
        return y0
    else:
        return np.mean(y)

def quote_result(name, value,  error, units):
    r = {"value":value,"error":error,"units":units}
    try:
        with open('../processed/results.json','r') as f:
            d = json.load(f)
    except:
        d = {}
    d[name]=r
    with open('../processed/results.json','w+') as f:
        
        json.dump(d,f)

def save_json(filename,obj):
    with open(filename,'w+') as f:
        json.dump(obj,f)
